@@ -12,20 +12,23 @@ if (!isGeneric("getValuesBlock")) {
 
 setMethod('getValuesBlock', signature(x='RasterStack', row='numeric'), 
 	function(x, row, nrows=1, col=1, ncols=(ncol(x)-col+1), lyrs) {
-		nl <- nlayers(x)
+		stopifnot(row <= x@nrows)
+		stopifnot(col <= x@ncols)
+		nrows <- min(round(nrows), x@nrows-row+1)
+		ncols <- min((x@ncols-col+1), ncols)
+		stopifnot(nrows > 0)
+		stopifnot(ncols > 0)
+
+		nlyrs <- nlayers(x)
 		if (missing(lyrs)) {
-			lyrs <- 1:nl
+			lyrs <- 1:nlyrs
 		} else {
 			lyrs <- lyrs[lyrs %in% 1:nl]
 			if (length(lyrs) == 0) {
 				stop("no valid layers selected")
 			}
+			nlyrs <- length(lyrs)
 		}
-		nlyrs <- length(lyrs)
-		nrows <- min(round(nrows), x@nrows-row+1)
-		ncols <- min((x@ncols-col+1), ncols)
-		stopifnot(nrows > 0)
-		stopifnot(ncols > 0)
 		
 		res <- matrix(ncol=nlyrs, nrow=nrows * ncols)
 		for (i in 1:nlyrs) {
@@ -40,7 +43,8 @@ setMethod('getValuesBlock', signature(x='RasterStack', row='numeric'),
 
 setMethod('getValuesBlock', signature(x='RasterBrick', row='numeric'), 
 	function(x, row, nrows=1, col=1, ncols=(ncol(x)-col+1), lyrs) {
-
+		stopifnot(row <= x@nrows)
+		stopifnot(col <= x@ncols)
 		nrows <- min(round(nrows), x@nrows-row+1)
 		ncols <- min((x@ncols-col+1), ncols)
 		stopifnot(nrows > 0)
