@@ -74,6 +74,8 @@
 		}
 		dsize <- dataSize(object@file@datanotation)
 		dsign <- dataSigned(object@file@datanotation)
+		if (dsize > 2) { dsign <- TRUE }
+
 		
 		object <- openConnection(object)
 		if (object@file@nbands > 1) {
@@ -98,7 +100,8 @@
 		}
 
 		if (object@file@datanotation == 'INT4U') {
-			result[result < 0] <- 2147483647 - result[result < 0] 
+			i <- !is.na(result) & result < 0
+			result[i] <- 2147483647 - result[i] 
 		}
 		if (dtype == 'numeric') {
 			result[result <= (0.999999 * object@file@nodatavalue)] <- NA 	
