@@ -22,7 +22,7 @@ if (!isGeneric('writeValues')) {
 setMethod('writeStart', signature(x='RasterLayer', filename='character'), 
 function(x, filename, options=NULL, format, ...) {
 
-	if (filename == '') { 
+	if (trim(filename) == '') { 
 		filename <- rasterTmpFile() 
 	}
 	filename <- .fullFilename(filename)
@@ -44,7 +44,7 @@ function(x, filename, options=NULL, format, ...) {
 setMethod('writeStart', signature(x='RasterBrick', filename='character'), 
 function(x, filename, options=NULL, format, ...) {
 
-	if (filename == '') { 
+	if (trim(filename) == '') { 
 		filename <- rasterTmpFile() 
 	}
 	filename <- .fullFilename(filename)
